@@ -68,11 +68,24 @@
 /* Allow TCP connections to the session manager. */
 #define ALLOW_TCP_KEY              GSM_GCONF_CONFIG_PREFIX "/allow_tcp_connections"
 
+/* Default chosen option at logout dialog */
+#define LOGOUT_OPTION_KEY	   GSM_GCONF_CONFIG_PREFIX "/logout_option"
+
 /* Assistive Technology support is turned on */
 #define ACCESSIBILITY_KEY         "/desktop/gnome/interface/accessibility"
 
+/* Proxy information */
+#define HTTP_PROXY_PREFIX             "/system/http_proxy"
+#define HTTP_PROXY_KEY                HTTP_PROXY_PREFIX "/use_http_proxy"
+#define HTTP_PROXY_AUTHENTICATION_KEY HTTP_PROXY_PREFIX "/use_authentication"
+#define HTTP_PROXY_USER_NAME_KEY      HTTP_PROXY_PREFIX "/authentication_user"
+#define HTTP_PROXY_PASSWORD_KEY       HTTP_PROXY_PREFIX "/authentication_password"
+#define HTTP_PROXY_HOST_KEY           HTTP_PROXY_PREFIX "/host"
+#define HTTP_PROXY_PORT_KEY           HTTP_PROXY_PREFIX "/port"
+
 /* Convenience macros: */
 #define APPEND(List,Elt) ((List) = (g_slist_append ((List), (Elt))))
+#define PREPEND(List,Elt) ((List) = (g_slist_prepend ((List), (Elt))))
 #define REMOVE(List,Elt) ((List) = (g_slist_remove ((List), (Elt))))
 #define CONCAT(L1,L2) ((L1) = (g_slist_concat ((L1), (L2))))
 
@@ -140,6 +153,9 @@ typedef struct
   /* If the client has been loaded from, or saved to, disk */
   gboolean session_saved;
 
+  /* Purge timeout ID; see start_client() */
+  guint purge_timeout_id;
+
   guint magic;
 } Client;
 
@@ -159,13 +175,13 @@ extern gchar *session_name;
 
 /* Milliseconds to wait for clients to register before assuming that
  * they have finished any initialisation needed by other clients. */
-extern guint purge_delay;
+extern gint purge_delay;
 
 /* Milliseconds to wait for clients to die before cutting our throat. */
-extern guint suicide_delay;
+extern gint suicide_delay;
 
 /* Milliseconds to wait for clients to complete save before reporting error. */
-extern guint warn_delay;
+extern gint warn_delay;
 
 /* Prompting for save session on logout. If true, session will automatically
  * save, if false, user will be prompted to have option of saving session on
